@@ -25,10 +25,13 @@ from context import Context
 from application import Application
 from autosave import Autosave
 from device_state import DeviceState
-from mime import Mime
+#from help import Help
+from locale import Locale
+#from mime import Mime
 from plugin import Plugin
 from rpc import Rpc
 from state_saving import StateSaving
 from statusbar import Statusbar
 from system_note import SystemNote
 from time_notification import TimeNotification
+#import ic
